
public abstract class CapitalStrategy
{
    public double capital(Loan loan)
    {
        // Standard formula for risk-adjusted capital:
        // Risk Amount x Duration x Risk Factor
        return riskAmountFor(loan) * duration(loan) * riskFactorFor(loan);
    }
    
    public abstract double riskAmountFor(Loan loan);
    
    public double duration(Loan loan)
    {
        return 0.0;
    }
    
    public double riskFactorFor(Loan loan)
    {
        return 0.0;
    }

    public double unusedRiskFactor(Loan loan)
    {
        return 0.0;
    }
}
